# JanuX

<img src="graphics/janux.svg" alt="JanuX Logo" align="right" width="200">

**Janus**, the Roman god of beginnings, transitions and duality, is known for his two faces. In Roman mythology, he symbolizes direction, beginnings, ends and contrasts.

---

**JanuX** is not a Roman god, but it is a robust yet simple tool for generating a set of path options in directed graphs. It is designed for efficient routing or creating path options for custom requirements.

---

## Examples

| ![Image1](graphics/gallery/a.png) | ![Image2](graphics/gallery/b.png) |
|------------------------|-----------------------|
| ![Image3](graphics/gallery/c.png) | ![Image4](graphics/gallery/d.png) |

---

![Image5](graphics/gallery/e.gif)

---

## License

This project is licensed under the [MIT License](LICENSE.txt).